@@ -84,6 +84,8 @@ class Job:
         return self
 
     def add_transformation(self, transformation: str, options: dict = None) -> "Job":
+        if options is None:
+            options = {}
         self.transformations.append({"name": transformation, "options": options})
         return self
 
